==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/inputs/VirtualNetworksPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.inputs

import com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * HybridAKSNetworkSpec defines the desired state of HybridAKSNetwork
 * @property dnsServers Address of the DNS servers associated with the network
 * @property gateway Address of the Gateway associated with the network
 * @property infraVnetProfile
 * @property ipAddressPrefix IP Address Prefix of the network
 * @property vipPool Virtual IP Pool for Kubernetes
 * @property vmipPool IP Pool for Virtual Machines
 */
public data class VirtualNetworksPropertiesArgs(
    public val dnsServers: Output<List<String>>? = null,
    public val gateway: Output<String>? = null,
    public val infraVnetProfile: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>? = null,
    public val ipAddressPrefix: Output<String>? = null,
    public val vipPool: Output<List<VirtualNetworksPropertiesVipPoolArgs>>? = null,
    public val vmipPool: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs =
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gateway(gateway?.applyValue({ args0 -> args0 }))
            .infraVnetProfile(infraVnetProfile?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .ipAddressPrefix(ipAddressPrefix?.applyValue({ args0 -> args0 }))
            .vipPool(
                vipPool?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .vmipPool(
                vmipPool?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualNetworksPropertiesArgs].
 */
@PulumiTagMarker
public class VirtualNetworksPropertiesArgsBuilder internal constructor() {
    private var dnsServers: Output<List<String>>? = null

    private var gateway: Output<String>? = null

    private var infraVnetProfile: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>? = null

    private var ipAddressPrefix: Output<String>? = null

    private var vipPool: Output<List<VirtualNetworksPropertiesVipPoolArgs>>? = null

    private var vmipPool: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>? = null

    /**
     * @param value Address of the DNS servers associated with the network
     */
    @JvmName("wlbhraoaixleamvk")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("fctrnvciktevxljl")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values Address of the DNS servers associated with the network
     */
    @JvmName("rebagfhjfjfstigd")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Address of the Gateway associated with the network
     */
    @JvmName("lakeejgwujblocln")
    public suspend fun gateway(`value`: Output<String>) {
        this.gateway = value
    }

    /**
     * @param value
     */
    @JvmName("gyvblhjexuvkwlgv")
    public suspend
    fun infraVnetProfile(`value`: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>) {
        this.infraVnetProfile = value
    }

    /**
     * @param value IP Address Prefix of the network
     */
    @JvmName("ooxkxefrqhwoxmcd")
    public suspend fun ipAddressPrefix(`value`: Output<String>) {
        this.ipAddressPrefix = value
    }

    /**
     * @param value Virtual IP Pool for Kubernetes
     */
    @JvmName("pnudxgtytbfupnyj")
    public suspend fun vipPool(`value`: Output<List<VirtualNetworksPropertiesVipPoolArgs>>) {
        this.vipPool = value
    }

    @JvmName("ufykgwmswlydjedh")
    public suspend fun vipPool(vararg values: Output<VirtualNetworksPropertiesVipPoolArgs>) {
        this.vipPool = Output.all(values.asList())
    }

    /**
     * @param values Virtual IP Pool for Kubernetes
     */
    @JvmName("dmupilesnslrlvjq")
    public suspend fun vipPool(values: List<Output<VirtualNetworksPropertiesVipPoolArgs>>) {
        this.vipPool = Output.all(values)
    }

    /**
     * @param value IP Pool for Virtual Machines
     */
    @JvmName("qbgnnhyxcemupsgj")
    public suspend fun vmipPool(`value`: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>) {
        this.vmipPool = value
    }

    @JvmName("dnhiwbevewyujfvj")
    public suspend fun vmipPool(vararg values: Output<VirtualNetworksPropertiesVmipPoolArgs>) {
        this.vmipPool = Output.all(values.asList())
    }

    /**
     * @param values IP Pool for Virtual Machines
     */
    @JvmName("rxfcikcjcdpenwqa")
    public suspend fun vmipPool(values: List<Output<VirtualNetworksPropertiesVmipPoolArgs>>) {
        this.vmipPool = Output.all(values)
    }

    /**
     * @param value Address of the DNS servers associated with the network
     */
    @JvmName("dlihkgxugyqsqtay")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values Address of the DNS servers associated with the network
     */
    @JvmName("dlqkgdoeudkunphi")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Address of the Gateway associated with the network
     */
    @JvmName("knujmutvpsoqhnoc")
    public suspend fun gateway(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param value
     */
    @JvmName("lipdifxsslmvyrbj")
    public suspend fun infraVnetProfile(`value`: VirtualNetworksPropertiesInfraVnetProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.infraVnetProfile = mapped
    }

    /**
     * @param argument
     */
    @JvmName("oshpaykaeorkwiai")
    public suspend
    fun infraVnetProfile(argument: suspend VirtualNetworksPropertiesInfraVnetProfileArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualNetworksPropertiesInfraVnetProfileArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.infraVnetProfile = mapped
    }

    /**
     * @param value IP Address Prefix of the network
     */
    @JvmName("rylwpdqwprusvrwa")
    public suspend fun ipAddressPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddressPrefix = mapped
    }

    /**
     * @param value Virtual IP Pool for Kubernetes
     */
    @JvmName("lnffuyxnmovfcwma")
    public suspend fun vipPool(`value`: List<VirtualNetworksPropertiesVipPoolArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("qnvgckdyehawirgs")
    public suspend
    fun vipPool(argument: List<suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("shqfxaygyqyfluks")
    public suspend fun vipPool(
        vararg
        argument: suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("vqtkcpehpgbdbgec")
    public suspend
    fun vipPool(argument: suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param values Virtual IP Pool for Kubernetes
     */
    @JvmName("jyevdkdrhinhcrot")
    public suspend fun vipPool(vararg values: VirtualNetworksPropertiesVipPoolArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vipPool = mapped
    }

    /**
     * @param value IP Pool for Virtual Machines
     */
    @JvmName("slsuptcxwtpfsmww")
    public suspend fun vmipPool(`value`: List<VirtualNetworksPropertiesVmipPoolArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("pxjdsmllxpnnpwmy")
    public suspend
    fun vmipPool(argument: List<suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("osmvqegqdkhuulec")
    public suspend fun vmipPool(
        vararg
        argument: suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("iiprkqagrvvagmxa")
    public suspend
    fun vmipPool(argument: suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param values IP Pool for Virtual Machines
     */
    @JvmName("njdpnybdkfggeevq")
    public suspend fun vmipPool(vararg values: VirtualNetworksPropertiesVmipPoolArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vmipPool = mapped
    }

    internal fun build(): VirtualNetworksPropertiesArgs = VirtualNetworksPropertiesArgs(
        dnsServers = dnsServers,
        gateway = gateway,
        infraVnetProfile = infraVnetProfile,
        ipAddressPrefix = ipAddressPrefix,
        vipPool = vipPool,
        vmipPool = vmipPool,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/inputs/VirtualNetworksPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.inputs

import com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * HybridAKSNetworkSpec defines the desired state of HybridAKSNetwork
 * @property dnsServers Address of the DNS servers associated with the network
 * @property gateway Address of the Gateway associated with the network
 * @property infraVnetProfile
 * @property ipAddressPrefix IP Address Prefix of the network
 * @property vipPool Virtual IP Pool for Kubernetes
 * @property vmipPool IP Pool for Virtual Machines
 */
public data class VirtualNetworksPropertiesArgs(
    public val dnsServers: Output<List<String>>? = null,
    public val gateway: Output<String>? = null,
    public val infraVnetProfile: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>? = null,
    public val ipAddressPrefix: Output<String>? = null,
    public val vipPool: Output<List<VirtualNetworksPropertiesVipPoolArgs>>? = null,
    public val vmipPool: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs =
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gateway(gateway?.applyValue({ args0 -> args0 }))
            .infraVnetProfile(infraVnetProfile?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .ipAddressPrefix(ipAddressPrefix?.applyValue({ args0 -> args0 }))
            .vipPool(
                vipPool?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .vmipPool(
                vmipPool?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualNetworksPropertiesArgs].
 */
@PulumiTagMarker
public class VirtualNetworksPropertiesArgsBuilder internal constructor() {
    private var dnsServers: Output<List<String>>? = null

    private var gateway: Output<String>? = null

    private var infraVnetProfile: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>? = null

    private var ipAddressPrefix: Output<String>? = null

    private var vipPool: Output<List<VirtualNetworksPropertiesVipPoolArgs>>? = null

    private var vmipPool: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>? = null

    /**
     * @param value Address of the DNS servers associated with the network
     */
    @JvmName("bsaylleqdvadoylg")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("iudqcyswklerydsi")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values Address of the DNS servers associated with the network
     */
    @JvmName("oxqhjsehshmbowwq")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Address of the Gateway associated with the network
     */
    @JvmName("rolvpwkrsoxxelvm")
    public suspend fun gateway(`value`: Output<String>) {
        this.gateway = value
    }

    /**
     * @param value
     */
    @JvmName("chbllknlnguwhpqb")
    public suspend
    fun infraVnetProfile(`value`: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>) {
        this.infraVnetProfile = value
    }

    /**
     * @param value IP Address Prefix of the network
     */
    @JvmName("iqbnqdxbycwshqfq")
    public suspend fun ipAddressPrefix(`value`: Output<String>) {
        this.ipAddressPrefix = value
    }

    /**
     * @param value Virtual IP Pool for Kubernetes
     */
    @JvmName("cxvkpiotmqwkuoaq")
    public suspend fun vipPool(`value`: Output<List<VirtualNetworksPropertiesVipPoolArgs>>) {
        this.vipPool = value
    }

    @JvmName("jilxxwvrmuptrmqr")
    public suspend fun vipPool(vararg values: Output<VirtualNetworksPropertiesVipPoolArgs>) {
        this.vipPool = Output.all(values.asList())
    }

    /**
     * @param values Virtual IP Pool for Kubernetes
     */
    @JvmName("oxxcilqcbmarndjj")
    public suspend fun vipPool(values: List<Output<VirtualNetworksPropertiesVipPoolArgs>>) {
        this.vipPool = Output.all(values)
    }

    /**
     * @param value IP Pool for Virtual Machines
     */
    @JvmName("jomuwvcbxkeqmpoi")
    public suspend fun vmipPool(`value`: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>) {
        this.vmipPool = value
    }

    @JvmName("yvflufcrtrnlnsoi")
    public suspend fun vmipPool(vararg values: Output<VirtualNetworksPropertiesVmipPoolArgs>) {
        this.vmipPool = Output.all(values.asList())
    }

    /**
     * @param values IP Pool for Virtual Machines
     */
    @JvmName("ewkmkjqjbglmaqsb")
    public suspend fun vmipPool(values: List<Output<VirtualNetworksPropertiesVmipPoolArgs>>) {
        this.vmipPool = Output.all(values)
    }

    /**
     * @param value Address of the DNS servers associated with the network
     */
    @JvmName("mrjnvyysprgqgyhd")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values Address of the DNS servers associated with the network
     */
    @JvmName("nprigwshbsoxjpmr")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Address of the Gateway associated with the network
     */
    @JvmName("yhrmlpfekdyntqnw")
    public suspend fun gateway(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param value
     */
    @JvmName("gjdpjuidxlxbtmuh")
    public suspend fun infraVnetProfile(`value`: VirtualNetworksPropertiesInfraVnetProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.infraVnetProfile = mapped
    }

    /**
     * @param argument
     */
    @JvmName("gplmcreuucrhmeqq")
    public suspend
    fun infraVnetProfile(argument: suspend VirtualNetworksPropertiesInfraVnetProfileArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualNetworksPropertiesInfraVnetProfileArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.infraVnetProfile = mapped
    }

    /**
     * @param value IP Address Prefix of the network
     */
    @JvmName("ryqjmsqmvtbalnes")
    public suspend fun ipAddressPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddressPrefix = mapped
    }

    /**
     * @param value Virtual IP Pool for Kubernetes
     */
    @JvmName("snspxplhswixxyyu")
    public suspend fun vipPool(`value`: List<VirtualNetworksPropertiesVipPoolArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("insmirfwrfmvhsxc")
    public suspend
    fun vipPool(argument: List<suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("xuhcygvnlecykpkq")
    public suspend fun vipPool(
        vararg
        argument: suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("kqbxclusaafvwsgr")
    public suspend
    fun vipPool(argument: suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param values Virtual IP Pool for Kubernetes
     */
    @JvmName("nawvovuuejuaspyc")
    public suspend fun vipPool(vararg values: VirtualNetworksPropertiesVipPoolArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vipPool = mapped
    }

    /**
     * @param value IP Pool for Virtual Machines
     */
    @JvmName("vyyeidxlpmmmgsql")
    public suspend fun vmipPool(`value`: List<VirtualNetworksPropertiesVmipPoolArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("oqwpajvusnmvpdck")
    public suspend
    fun vmipPool(argument: List<suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("gipniahnpmbbywih")
    public suspend fun vmipPool(
        vararg
        argument: suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("oruknvfkvnxytusc")
    public suspend
    fun vmipPool(argument: suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param values IP Pool for Virtual Machines
     */
    @JvmName("sgroqgfpmtpmuhhl")
    public suspend fun vmipPool(vararg values: VirtualNetworksPropertiesVmipPoolArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vmipPool = mapped
    }

    internal fun build(): VirtualNetworksPropertiesArgs = VirtualNetworksPropertiesArgs(
        dnsServers = dnsServers,
        gateway = gateway,
        infraVnetProfile = infraVnetProfile,
        ipAddressPrefix = ipAddressPrefix,
        vipPool = vipPool,
        vmipPool = vmipPool,
    )
}
